@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.63 2006/02/13 16:45:34 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.64 2006/07/16 13:32:59 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
@@ -817,7 +817,8 @@ S-expression."))
                           start end
                           match-start match-end
                           reg-starts reg-ends
-                          simple-calls)
+                          simple-calls
+                          element-type)
   (declare #.*standard-optimize-settings*)
   "Accepts a replacement template and the current values from the
 matching process in REGEX-REPLACE or REGEX-REPLACE-ALL and returns the
@@ -827,7 +828,7 @@ corresponding template."
   (let ((reg-bound (if reg-starts
                      (array-dimension reg-starts 0)
                      0)))
-    (with-output-to-string (s)
+    (with-output-to-string (s nil :element-type element-type)
       (loop for token in replacement-template
             do (typecase token
                  (string
@@ -902,8 +903,8 @@ corresponding template."
                                        reg-starts reg-ends)))
                        s)))))))))
 
-(defun replace-aux (target-string replacement pos-list reg-list
-                                  start end preserve-case simple-calls)
+(defun replace-aux (target-string replacement pos-list reg-list start end
+                                  preserve-case simple-calls element-type)
   (declare #.*standard-optimize-settings*)
   "Auxiliary function used by REGEX-REPLACE and
 REGEX-REPLACE-ALL. POS-LIST contains a list with the start and end
@@ -911,7 +912,7 @@ positions of all matches while REG-LIST contains a list of arrays
 representing the corresponding register start and end positions."
   ;; build the template once before we start the loop
   (let ((replacement-template (build-replacement-template replacement)))
-    (with-output-to-string (s)
+    (with-output-to-string (s nil :element-type element-type)
       ;; loop through all matches and take the start and end of the
       ;; whole string into account
       (loop for (from to) on (append (list start) pos-list (list end))
@@ -926,7 +927,8 @@ representing the corresponding register start and end positions."
                                                         start end
                                                         from to
                                                         reg-starts reg-ends
-                                                        simple-calls)
+                                                        simple-calls
+                                                        element-type)
                                      nil)
             while to
             if replace
@@ -947,7 +949,8 @@ representing the corresponding register start and end positions."
                             &key (start 0)
                             (end (length target-string))
                             preserve-case
-                            simple-calls)
+                            simple-calls
+                            (element-type 'character))
   (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
 replace the first match with REPLACEMENT.
@@ -974,14 +977,17 @@ representing register (1+ N) -, or a function designator.
   If PRESERVE-CASE is true, the replacement will try to preserve the
 case (all upper case, all lower case, or capitalized) of the
 match. The result will always be a fresh string, even if REGEX doesn't
-match."
+match.
+
+  ELEMENT-TYPE is the element type of the resulting string."
   (multiple-value-bind (match-start match-end reg-starts reg-ends)
       (scan regex target-string :start start :end end)
     (if match-start
       (replace-aux target-string replacement
                    (list match-start match-end)
                    (list reg-starts reg-ends)
-                   start end preserve-case simple-calls)
+                   start end preserve-case
+                   simple-calls element-type)
       (subseq target-string start end))))
 
 #-:cormanlisp
@@ -997,7 +1003,8 @@ match."
                                 &key (start 0)
                                      (end (length target-string))
                                      preserve-case
-                                     simple-calls)
+                                     simple-calls
+                                     (element-type 'character))
   (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
 replace all matches with REPLACEMENT.
@@ -1024,7 +1031,9 @@ representing register (1+ N) -, or a function designator.
   If PRESERVE-CASE is true, the replacement will try to preserve the
 case (all upper case, all lower case, or capitalized) of the
 match. The result will always be a fresh string, even if REGEX doesn't
-match."
+match.
+
+  ELEMENT-TYPE is the element type of the resulting string."
   (let ((pos-list '())
         (reg-list '()))
     (do-scans (match-start match-end reg-starts reg-ends regex target-string
@@ -1038,7 +1047,8 @@ match."
       (replace-aux target-string replacement
                    (nreverse pos-list)
                    (nreverse reg-list)
-                   start end preserve-case simple-calls)
+                   start end preserve-case
+                   simple-calls element-type)
       (subseq target-string start end))))
 
 #-:cormanlisp
